@@ -2,8 +2,10 @@ package Msql;
 
 require Msql::Statement;
 
-$VERSION = $VERSION = "1.00";
-# $Revision: 1.84 $$Date: 1995/07/08 19:23:09 $$RCSfile: Msql.pm,v $
+$VERSION = $VERSION = "1.01";
+# $Revision: 1.86 $$Date: 1995/07/30 21:13:48 $$RCSfile: Msql.pm,v $
+
+$QUIET = $QUIET = 0;
 
 require Carp;
 require AutoLoader;
@@ -112,8 +114,6 @@ The Msql Perl Adaptor: Simple Perl interface to the mSQL database
   @arr = ListDBs     $dbh;
   @arr = ListTables  $dbh;
 	
-  Insert             $dbh $table, $value [, $value]... ;
-	
   @arr = FetchRow    $sth;
 	
   DataSeek           $sth $row_number;
@@ -124,9 +124,9 @@ This package is designed as close as possible to its C API
 counterpart. The manual that comes with mSQL describes most things you
 need. 
 
-Internally you are dealing with the two classes Msql and
-Msql::Statement. You will never see the latter, because you reach it
-through a statement handle returned by a Query or a ListFields
+Internally you are dealing with the two classes C<Msql> and
+C<Msql::Statement>. You will never see the latter, because you reach
+it through a statement handle returned by a Query or a ListFields
 statement. The only class you name explicitly is Msql. It offers you
 the Connect command:
 
@@ -135,40 +135,34 @@ the Connect command:
   $dbh = Connect Msql $host, $database;
 
 This connects you with the desired host/database. With no argument or
-with "localhost" as the first argument connects to the UNIX socket
-/dev/msql, which is a performance gain. A database name as the second
-argument selects the chosen database within the connection. The return
-value is a database handle. You will need this handle to gain further
-access to the database. Issue multiple C<Connect> statements -- no
-problem.
+with an empty string as the first argument it connects to the UNIX
+socket /dev/msql, which is a big performance gain. A database name as
+the second argument selects the chosen database within the
+connection. The return value is a database handle if the Connect
+succeeds, otherwise the return value is undef.
+
+You will need this handle to gain further access to the
+database. Issue multiple C<Connect> statements -- no problem.
 
   SelectDB $dbh $database;
 
-If you haven't chosen a database with the C<Connect> command, or if you
-want to change the connection to a different database using a database
-handle you have got from a previous C<Connect>, then use SelectDB.
+If you have not chosen a database with the C<Connect> command, or if
+you want to change the connection to a different database using a
+database handle you have got from a previous C<Connect>, then use
+SelectDB.
 
   $sth = ListFields  $dbh $table;
   $sth = Query       $dbh $sql_statement;
 
-These two work rather similar as descibed in David's manual. They return
+These two work rather similar as descibed in the mSQL manual. They return
 a statement handle which lets you further explore what the server has
-to tell you.
+to tell you. On error the return value is undef.
 
   @arr = ListDBs     $dbh;
   @arr = ListTables  $dbh;
 
 An array is returned that contains the requested names without any
-further information. The second wont
-
-  Insert      $dbh $table, $value [, $value]... ; # discouraged
-
-This is a handy method defined in Msql.pm mainly for
-illustration. Insert() constructs for you a full SQL insert
-statement. You have to supply the correct number of columns
-though. Insert calls ListFields for you to fill in the SQL insert
-statement correctly. Beware, this is a big performance loss against
-your own supplied SQL insert statement.
+further information.
 
   @arr = FetchRow   $sth;
 
@@ -233,14 +227,14 @@ $sth knows about all metadata that are provided by the API:
 
   $scalar = $sth->numrows;    
   $scalar = $sth->numfields;  
-  @array  = $sth->table;       the names of the tables of each column
-  @array  = $sth->name;        the names of the columns
-  @array  = $sth->type;        the type of each column, defined in msql.h
-		               and accessible via &Msql::CHAR_TYPE,
-		               &Msql::INT_TYPE, &Msql::REAL_TYPE,
-  @array  = $sth->is_not_null; array of boolean
-  @array  = $sth->is_pri_key;  array of boolean
-  @array  = $sth->length;      array of the length of each field in bytes
+  $arrref  = $sth->table;       the names of the tables of each column
+  $arrref  = $sth->name;        the names of the columns
+  $arrref  = $sth->type;        the type of each column, defined in msql.h
+		                and accessible via &Msql::CHAR_TYPE,
+		                &Msql::INT_TYPE, &Msql::REAL_TYPE,
+  $arrref  = $sth->is_not_null; array of boolean
+  $arrref  = $sth->is_pri_key;  array of boolean
+  $arrref  = $sth->length;      array of the length of each field in bytes
 
 
 =head2 The C<-w> switch
@@ -254,6 +248,10 @@ the environment variables that are described in David's
 manual. David's debugging aid is excellent, there's nothing to be
 added.
 
+If you want to use the -w switch but do not want to see the error
+messages from the msql daemon, you can set the variable $Msql::QUIET
+to some true value, and they will be suppressed.
+
 =head1 PREREQUISITES
 
 mSQL is a libmsql.a library written by David Hughes
